@@ -120,7 +120,7 @@ class FocalLoss(nn.Module):
 
     def __str__(self):
         if self.alpha is None:
-            return "Focal (alpha: [0.5, 0.5], gamma: %f)"
+            return "Focal (alpha: [0.5, 0.5], gamma: %f)" % (self.gamma)
         else:
             return "Focal (alpha: %s, gamma: %f)" % (self.alpha, self.gamma)
 
@@ -145,7 +145,7 @@ class DiceLoss(nn.Module):
         dice = 0
         for c in range(1, logits.size(1)):
             p = probs[:, c:c + 1, ...]
-            t = (target == c).long()
+            t = (target == c).float()
 
             # reshape everything to vectors
             p = p.contiguous().view(-1)
